const Mesa = require('vendor/Mesa.js');

/**
 * A Mesa Script exports a class with a script() method.
 */
module.exports = new class {

  /**
   * Mesa Script
   *
   * @param {object} payload The payload data
   * @param {object} context Additional context about this task
   */
  script = (payload, context) => {
    let order = context.steps.shopify;
    let vars = context.steps;

    let credential = JSON.parse(Mesa.credential.get('chatgpt'));
    // Add your custom code here
    let options = {
      "headers": {
        "Content-Type": "application\/json",
        "Authorization": "Bearer " + credential.apikey,
      },
      "timeout": 120
    }

    let url = 'https://api.openai.com/v1/chat/completions';

    let messages = [
      {
        "role": "system",
        "content": `You're going to receive a set of prompts with each prompt having a numbered list of product reviews in them. 
        You're going to summarize the reviews in a paragraph under 80 words with an emphasis on the positive reviews.
        `,
      }
    ]

    for (let part of vars.custom.parts) {
      messages.push({
        "role": "user",
        "content": part,
      });
    }

    let data = {
      "model": "gpt-4-0613",
      "messages": messages,
    };

    let result = Mesa.request.post(url, data, options);
    Mesa.log.info('result', result);

    let newPayload = {
      "summary": result.choices[0].message.content,
    };
    Mesa.output.next(newPayload);
  }
}